@@ -125,6 +125,7 @@ name(NULL),
 console(NULL),
 controls(NULL),
 disable_context_menu(FALSE),
+disable_fullscreen(FALSE),
 event_mediacomplete(NULL),
 event_destroy(NULL),
 event_mousedown(NULL),
@@ -240,6 +241,8 @@ NPError nsPluginInstance::SetWindow(NPWindow * aWindow)
         argvn[arg++] = g_strdup_printf("--autostart=%i", autostart);
         if (disable_context_menu == TRUE)
             argvn[arg++] = g_strdup_printf("--disablecontextmenu");
+        if (disable_fullscreen == TRUE)
+            argvn[arg++] = g_strdup_printf("--disablefullscreen");
         if (debug == TRUE)
             argvn[arg++] = g_strdup_printf("--verbose");
         if (name != NULL)
@@ -461,6 +464,7 @@ int32 nsPluginInstance::WriteReady(NPStream * stream)
             g_strlcpy(item->src, stream->url, 1024);
             item->requested = TRUE;
             item->play = TRUE;
+            item->streaming = streaming(item->src);
             playlist = g_list_append(playlist, item);
             stream->notifyData = item;
         } else {
@@ -531,7 +535,7 @@ int32 nsPluginInstance::Write(NPStream * stream, int32 offset, int32 len, void *
     if (item->cancelled || item->retrieved)
         NPN_DestroyStream(mInstance, stream, NPRES_USER_BREAK);
 
-    if (strstr((char *) buffer, "ICY 200 OK") != NULL) {
+    if (strstr((char *) buffer, "ICY 200 OK") != NULL || item->streaming == TRUE) {
         item->streaming = TRUE;
         open_location(this, item, FALSE);
         item->requested = TRUE;
@@ -561,6 +565,7 @@ int32 nsPluginInstance::Write(NPStream * stream, int32 offset, int32 len, void *
         item->mediasize = stream->end;
 
     if (playerready) {
+        percent = 0.0;
         if (item->mediasize > 0) {
 
             percent = (gdouble) item->localsize / (gdouble) item->mediasize;
@@ -589,8 +594,9 @@ int32 nsPluginInstance::Write(NPStream * stream, int32 offset, int32 len, void *
             if (ok_to_play == FALSE && (item->localsize > (cache_size * 2 * 1024)) && (cache_size >= 512))
                 ok_to_play = TRUE;
             if (ok_to_play == FALSE) {
-                if (item->bitrate == 0) {
+                if (item->bitrate == 0 && item->bitrate_requests < 5) {
                     item->bitrate = request_bitrate(this,item,item->local);
+                    item->bitrate_requests++;
                 }
                 if (item->bitrate > 0) {
                     if (item->localsize / item->bitrate >= 10) {
@@ -598,6 +604,7 @@ int32 nsPluginInstance::Write(NPStream * stream, int32 offset, int32 len, void *
                     }
                 }
             }
+            
         }        
         // if not opened, over cache level and not an href target then try and open it
         if ((!item->opened) && ok_to_play == TRUE) {
