@@ -212,6 +212,16 @@ void new_instance(nsPluginInstance * instance, nsPluginCreateData * parameters)
                     instance->disable_context_menu = FALSE;
                 }
             }
+            
+            if (g_ascii_strcasecmp(parameters->argn[i], "enablefullscreen") == 0) {
+                if (g_ascii_strcasecmp(parameters->argv[i], "false") == 0
+                    || g_ascii_strcasecmp(parameters->argv[i], "no") == 0
+                    || g_ascii_strcasecmp(parameters->argv[i], "0") == 0) {
+                    instance->disable_fullscreen = TRUE;
+                } else {
+                    instance->disable_fullscreen = FALSE;
+                }
+            }
 
             if ((g_ascii_strcasecmp(parameters->argn[i], "loop") == 0)
                 || (g_ascii_strcasecmp(parameters->argn[i], "autorewind")
@@ -398,6 +408,7 @@ void new_instance(nsPluginInstance * instance, nsPluginCreateData * parameters)
 gint streaming(gchar * url)
 {
     gint ret = 0;
+    char *p;
 
     if (g_ascii_strncasecmp(url, "mms://", 6) == 0)
         ret = 1;
@@ -417,5 +428,15 @@ gint streaming(gchar * url)
     if (g_ascii_strncasecmp(url, "dvd://", 6) == 0)
         ret = 1;
 
+    if (g_ascii_strncasecmp(url, "file://", 7) == 0) {
+        p = g_filename_from_uri(url,NULL,NULL);
+        if (p != NULL) {
+            if (g_file_test(p, G_FILE_TEST_EXISTS)) {
+                g_strlcpy(url, p, 1024);
+                ret = 1;
+            }
+            g_free(p);
+        }
+    }
     return ret;
 }
