@@ -50,6 +50,8 @@ gchar *GetMIMEDescription()
               "audio/x-mpeg:mpg,mpeg:MPEG;"
               "audio/mpeg2:mp2:MPEG audio;"
               "audio/x-mpeg2:mp2:MPEG audio;"
+              "audio/mp4:mp4:MPEG 4 audio;"
+              "audio/x-mp4:mp4:MPEG 4 audio;"
               "video/mp4:mp4:MPEG 4 Video;"
               "video/x-m4v:m4v:MPEG 4 Video;" "video/3gpp:mp4,3gp:MPEG 4 Video;",
               sizeof(MimeTypes));
@@ -107,7 +109,7 @@ NPError PluginGetValue(NPPVariable variable, void *value)
     }
     if (variable == NPPVpluginDescriptionString) {
         *((const char **) value) =
-            "<a href=\"http://dekorte.homeip.net/download/gnome-mplayer/\">Gecko Media Player</a> "
+            "<a href=\"http://kdekorte.googlepages.com/gecko-mediaplayer\">Gecko Media Player</a> "
             VERSION
             "<br><br>Video Player Plug-in for QuickTime, RealPlayer and Windows Media Player streams using <a href=\"http://mplayerhq.hu\">MPlayer</a>";
 
